==> cxf-services-xkms-common-3.5.8-sources.jar: org/apache/cxf/xkms/model/xkms/UnverifiedKeyBindingType.java <==

package org.apache.cxf.xkms.model.xkms;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for UnverifiedKeyBindingType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="UnverifiedKeyBindingType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://www.w3.org/2002/03/xkms#}KeyBindingAbstractType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}ValidityInterval" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "UnverifiedKeyBindingType", propOrder = {
    "validityInterval"
})
@XmlSeeAlso({
    KeyBindingType.class
})
public class UnverifiedKeyBindingType
    extends KeyBindingAbstractType
{

    @XmlElement(name = "ValidityInterval")
    protected ValidityIntervalType validityInterval;

    /**
     * Gets the value of the validityInterval property.
     * 
     * @return
     *     possible object is
     *     {@link ValidityIntervalType }
     *     
     */
    public ValidityIntervalType getValidityInterval() {
        return validityInterval;
    }

    /**
     * Sets the value of the validityInterval property.
     * 
     * @param value
     *     allowed object is
     *     {@link ValidityIntervalType }
     *     
     */
    public void setValidityInterval(ValidityIntervalType value) {
        this.validityInterval = value;
    }

}

==> cxf-services-xkms-common-4.0.0-sources.jar: org/apache/cxf/xkms/model/xkms/UnverifiedKeyBindingType.java <==

package org.apache.cxf.xkms.model.xkms;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlSeeAlso;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for UnverifiedKeyBindingType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="UnverifiedKeyBindingType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://www.w3.org/2002/03/xkms#}KeyBindingAbstractType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}ValidityInterval" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "UnverifiedKeyBindingType", propOrder = {
    "validityInterval"
})
@XmlSeeAlso({
    KeyBindingType.class
})
public class UnverifiedKeyBindingType
    extends KeyBindingAbstractType
{

    @XmlElement(name = "ValidityInterval")
    protected ValidityIntervalType validityInterval;

    /**
     * Gets the value of the validityInterval property.
     * 
     * @return
     *     possible object is
     *     {@link ValidityIntervalType }
     *     
     */
    public ValidityIntervalType getValidityInterval() {
        return validityInterval;
    }

    /**
     * Sets the value of the validityInterval property.
     * 
     * @param value
     *     allowed object is
     *     {@link ValidityIntervalType }
     *     
     */
    public void setValidityInterval(ValidityIntervalType value) {
        this.validityInterval = value;
    }

}
